@@ -46,8 +46,8 @@
 #define DEFAULT_REL_ICONSDIR "/var/www/localhost/icons"
 #define DEFAULT_EXP_HTDOCSDIR "/var/www/localhost/htdocs"
 #define DEFAULT_REL_HTDOCSDIR "/var/www/localhost/htdocs"
-#define DEFAULT_EXP_MANUALDIR "/usr/share/doc/apache-2.4.58/manual"
-#define DEFAULT_REL_MANUALDIR "share/doc/apache-2.4.58/manual"
+#define DEFAULT_EXP_MANUALDIR "/usr/share/doc/apache-2.4.63-r1/manual"
+#define DEFAULT_REL_MANUALDIR "share/doc/apache-2.4.63-r1/manual"
 #define DEFAULT_EXP_CGIDIR "/var/www/localhost/cgi-bin"
 #define DEFAULT_REL_CGIDIR "/var/www/localhost/cgi-bin"
 #define DEFAULT_EXP_INCLUDEDIR "/usr/include/apache2"
